window.Gleam.initSearch([{"doc":"gloop","title":"gloop","content":"# gloop\n\n[![Package Version](https://img.shields.io/hexpm/v/gloop)](https://hex.pm/packages/gloop)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gloop/)\n\nStack-safe, non-UI blocking &quot;while&quot; and &quot;do while&quot; loops in Gleam to reduce the mental burden caused by recursion.\n\n```sh\ngleam add gloop\n```\nCheck the test folder for an example on how to use the while loop.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gloop&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"gloop","title":"blocking_do_while","content":"pub fn blocking_do_while(\n  state state: a,\n  code_to_run code_to_run: fn(a) -&gt; a,\n  post_run_condition post_run_condition: fn(a) -&gt; Bool,\n) -&gt; a\n This blocking `do while` function checks the condition based on the communicated state at the end\n of a iteration. It therefore runs the code AT LEAST once.\n As the other blocking while function it is stack-safe and a few milliseconds faster than the\n non-blocking do while function. As before, it should not be used in the majority of cases.\nSynonyms:\ngloop.blocking_do_while\ngloop blocking_do_while","url":"gloop.html#blocking_do_while"},{"doc":"gloop","title":"blocking_while","content":"pub fn blocking_while(\n  state state: a,\n  pre_run_condition pre_run_condition: fn(a) -&gt; Bool,\n  code_to_run code_to_run: fn(a) -&gt; a,\n) -&gt; a\n This blocking `while` function is stack-safe and checks the condition based on the\n communicated state.\n If the condition is true then the code is run and a new state is generated for the next iteration.\n If the condition is false then the code returns the final state and stops.\n As long as the condition is true, the while loop will continue without blowing up the stack.\n NOTE that this fuction blocks the UI from updating. It is slightly (a few msecs)\n faster than the non-blocking while function so if pure speed is what you are after\n AND you have a good idea of how many loops the function will execute then this function\n might be what you are after. In most cases ( &gt;95% ) this is NOT the function you should use.\nSynonyms:\ngloop.blocking_while\ngloop blocking_while","url":"gloop.html#blocking_while"},{"doc":"gloop","title":"do_while","content":"pub fn do_while(\n  state state: a,\n  code_to_run code_to_run: fn(a) -&gt; a,\n  post_run_condition post_run_condition: fn(a) -&gt; Bool,\n) -&gt; a\n This non-blocking `do while` function does the same thing as the blocking do while function,\n is stack-safe and does not block the UI.\n Again this is the function to select in the overwhelming majority of cases.\nSynonyms:\ngloop.do_while\ngloop do_while","url":"gloop.html#do_while"},{"doc":"gloop","title":"while","content":"pub fn while(\n  state state: a,\n  pre_run_condition pre_run_condition: fn(a) -&gt; Bool,\n  code_to_run code_to_run: fn(a) -&gt; a,\n) -&gt; a\n This `while` function does the same thing as the blocking while function BUT does not block\n the UI from updating and is stack-safe. This is the function to use in the overwhelming\n majority of cases.\nSynonyms:\ngloop.while\ngloop while","url":"gloop.html#while"},{"doc":"gloop","title":"gloop","content":" This module called `Gloop` introduces stack-safe, tall-call recursive, non-UI blocking `while` loops in Gleam\n The intent is to remove the additional mental burden recursion causes in Gleam.\n\n For an example of how to use this library see gloop_test.gleam in the test folder.","url":"gloop.html"}]);